==> kubernetes-model-policy-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/RuntimeClassStrategyOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RuntimeClassStrategyOptionsFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1beta1.RuntimeClassStrategyOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1beta1.RuntimeClassStrategyOptionsFluent<A>{
  public RuntimeClassStrategyOptionsFluentImpl() {
  }
  public RuntimeClassStrategyOptionsFluentImpl(io.fabric8.kubernetes.api.model.policy.v1beta1.RuntimeClassStrategyOptions instance) {
    this.withAllowedRuntimeClassNames(instance.getAllowedRuntimeClassNames()); 
    this.withDefaultRuntimeClassName(instance.getDefaultRuntimeClassName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();
  private java.lang.String defaultRuntimeClassName;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAllowedRuntimeClassNames(java.lang.Integer index,java.lang.String item) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    this.allowedRuntimeClassNames.add(index, item);
    return (A)this;
  }
  public A setToAllowedRuntimeClassNames(java.lang.Integer index,java.lang.String item) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    this.allowedRuntimeClassNames.set(index, item); return (A)this;
  }
  public A addToAllowedRuntimeClassNames(java.lang.String... items) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedRuntimeClassNames.add(item);} return (A)this;
  }
  public A addAllToAllowedRuntimeClassNames(java.util.Collection<java.lang.String> items) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedRuntimeClassNames.add(item);} return (A)this;
  }
  public A removeFromAllowedRuntimeClassNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.allowedRuntimeClassNames!= null){ this.allowedRuntimeClassNames.remove(item);}} return (A)this;
  }
  public A removeAllFromAllowedRuntimeClassNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.allowedRuntimeClassNames!= null){ this.allowedRuntimeClassNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAllowedRuntimeClassNames() {
    return this.allowedRuntimeClassNames;
  }
  public java.lang.String getAllowedRuntimeClassName(java.lang.Integer index) {
    return this.allowedRuntimeClassNames.get(index);
  }
  public java.lang.String getFirstAllowedRuntimeClassName() {
    return this.allowedRuntimeClassNames.get(0);
  }
  public java.lang.String getLastAllowedRuntimeClassName() {
    return this.allowedRuntimeClassNames.get(allowedRuntimeClassNames.size() - 1);
  }
  public java.lang.String getMatchingAllowedRuntimeClassName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedRuntimeClassNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAllowedRuntimeClassName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedRuntimeClassNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAllowedRuntimeClassNames(java.util.List<java.lang.String> allowedRuntimeClassNames) {
    if (allowedRuntimeClassNames != null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : allowedRuntimeClassNames){this.addToAllowedRuntimeClassNames(item);}} else { this.allowedRuntimeClassNames = null;} return (A) this;
  }
  public A withAllowedRuntimeClassNames(java.lang.String... allowedRuntimeClassNames) {
    if (this.allowedRuntimeClassNames != null) {this.allowedRuntimeClassNames.clear();}
    if (allowedRuntimeClassNames != null) {for (java.lang.String item :allowedRuntimeClassNames){ this.addToAllowedRuntimeClassNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasAllowedRuntimeClassNames() {
    return allowedRuntimeClassNames != null && !allowedRuntimeClassNames.isEmpty();
  }
  public A addNewAllowedRuntimeClassName(java.lang.String arg0) {
    return (A)addToAllowedRuntimeClassNames(new String(arg0));
  }
  public java.lang.String getDefaultRuntimeClassName() {
    return this.defaultRuntimeClassName;
  }
  public A withDefaultRuntimeClassName(java.lang.String defaultRuntimeClassName) {
    this.defaultRuntimeClassName=defaultRuntimeClassName; return (A) this;
  }
  public java.lang.Boolean hasDefaultRuntimeClassName() {
    return this.defaultRuntimeClassName != null;
  }
  
  /**
   * Method is deprecated. use withDefaultRuntimeClassName instead.
   */
  @java.lang.Deprecated
  public A withNewDefaultRuntimeClassName(java.lang.String arg0) {
    return (A)withDefaultRuntimeClassName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RuntimeClassStrategyOptionsFluentImpl that = (RuntimeClassStrategyOptionsFluentImpl) o;
    if (allowedRuntimeClassNames != null ? !allowedRuntimeClassNames.equals(that.allowedRuntimeClassNames) :that.allowedRuntimeClassNames != null) return false;
    if (defaultRuntimeClassName != null ? !defaultRuntimeClassName.equals(that.defaultRuntimeClassName) :that.defaultRuntimeClassName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedRuntimeClassNames,  defaultRuntimeClassName,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-policy-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/RuntimeClassStrategyOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RuntimeClassStrategyOptionsFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1beta1.RuntimeClassStrategyOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1beta1.RuntimeClassStrategyOptionsFluent<A>{
  public RuntimeClassStrategyOptionsFluentImpl() {
  }
  public RuntimeClassStrategyOptionsFluentImpl(io.fabric8.kubernetes.api.model.policy.v1beta1.RuntimeClassStrategyOptions instance) {
    this.withAllowedRuntimeClassNames(instance.getAllowedRuntimeClassNames()); 
    this.withDefaultRuntimeClassName(instance.getDefaultRuntimeClassName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();
  private java.lang.String defaultRuntimeClassName;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAllowedRuntimeClassNames(java.lang.Integer index,java.lang.String item) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    this.allowedRuntimeClassNames.add(index, item);
    return (A)this;
  }
  public A setToAllowedRuntimeClassNames(java.lang.Integer index,java.lang.String item) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    this.allowedRuntimeClassNames.set(index, item); return (A)this;
  }
  public A addToAllowedRuntimeClassNames(java.lang.String... items) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedRuntimeClassNames.add(item);} return (A)this;
  }
  public A addAllToAllowedRuntimeClassNames(java.util.Collection<java.lang.String> items) {
    if (this.allowedRuntimeClassNames == null) {this.allowedRuntimeClassNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedRuntimeClassNames.add(item);} return (A)this;
  }
  public A removeFromAllowedRuntimeClassNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.allowedRuntimeClassNames!= null){ this.allowedRuntimeClassNames.remove(item);}} return (A)this;
  }
  public A removeAllFromAllowedRuntimeClassNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.allowedRuntimeClassNames!= null){ this.allowedRuntimeClassNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAllowedRuntimeClassNames() {
    return this.allowedRuntimeClassNames;
  }
  public java.lang.String getAllowedRuntimeClassName(java.lang.Integer index) {
    return this.allowedRuntimeClassNames.get(index);
  }
  public java.lang.String getFirstAllowedRuntimeClassName() {
    return this.allowedRuntimeClassNames.get(0);
  }
  public java.lang.String getLastAllowedRuntimeClassName() {
    return this.allowedRuntimeClassNames.get(allowedRuntimeClassNames.size() - 1);
  }
  public java.lang.String getMatchingAllowedRuntimeClassName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedRuntimeClassNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAllowedRuntimeClassName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedRuntimeClassNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAllowedRuntimeClassNames(java.util.List<java.lang.String> allowedRuntimeClassNames) {
    if (allowedRuntimeClassNames != null) {this.allowedRuntimeClassNames = new java.util.ArrayList(); for (java.lang.String item : allowedRuntimeClassNames){this.addToAllowedRuntimeClassNames(item);}} else { this.allowedRuntimeClassNames = null;} return (A) this;
  }
  public A withAllowedRuntimeClassNames(java.lang.String... allowedRuntimeClassNames) {
    if (this.allowedRuntimeClassNames != null) {this.allowedRuntimeClassNames.clear();}
    if (allowedRuntimeClassNames != null) {for (java.lang.String item :allowedRuntimeClassNames){ this.addToAllowedRuntimeClassNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasAllowedRuntimeClassNames() {
    return allowedRuntimeClassNames != null && !allowedRuntimeClassNames.isEmpty();
  }
  public A addNewAllowedRuntimeClassName(java.lang.String arg0) {
    return (A)addToAllowedRuntimeClassNames(new String(arg0));
  }
  public java.lang.String getDefaultRuntimeClassName() {
    return this.defaultRuntimeClassName;
  }
  public A withDefaultRuntimeClassName(java.lang.String defaultRuntimeClassName) {
    this.defaultRuntimeClassName=defaultRuntimeClassName; return (A) this;
  }
  public java.lang.Boolean hasDefaultRuntimeClassName() {
    return this.defaultRuntimeClassName != null;
  }
  
  /**
   * Method is deprecated. use withDefaultRuntimeClassName instead.
   */
  @java.lang.Deprecated
  public A withNewDefaultRuntimeClassName(java.lang.String arg0) {
    return (A)withDefaultRuntimeClassName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RuntimeClassStrategyOptionsFluentImpl that = (RuntimeClassStrategyOptionsFluentImpl) o;
    if (allowedRuntimeClassNames != null ? !allowedRuntimeClassNames.equals(that.allowedRuntimeClassNames) :that.allowedRuntimeClassNames != null) return false;
    if (defaultRuntimeClassName != null ? !defaultRuntimeClassName.equals(that.defaultRuntimeClassName) :that.defaultRuntimeClassName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedRuntimeClassNames,  defaultRuntimeClassName,  additionalProperties,  super.hashCode());
  }
  
}
